/* [REQUIRED CSS] */
.x-grid3-gridsummary-hide-hscroll{overflow-x:hidden;overflow-y:auto;}
.x-grid3-hide-gridsummary .x-grid3-gridsummary-row-inner{display:none;}


/* [OPTIONAL CSS] -- example styles for GridSummary row */
.x-grid3-summary-row{border-left:1px solid #fff;border-right:1px solid #fff;color:#333;background:#f1f2f4;}
.x-grid3-summary-row .x-grid3-cell-inner{font-weight:bold;padding-bottom:4px;}
.x-grid3-cell-first .x-grid3-cell-inner{padding-left:16px;}
.x-grid3-hide-summary .x-grid3-summary-row{display:none;}
.x-grid3-summary-msg{padding:4px 16px;font-weight:bold;}
