/**
 * Календарь на базе Sencha Calendar
 */

Ext.m3.Calendar = Ext.extend(Ext.calendar.CalendarPanel, {
    constructor: function(baseConfig, params){
        Ext.m3.Calendar.superclass.constructor.call(this, baseConfig);
    }
})
