.icon-accept {
    background-image:url(../icons/accept.png) !important;
}
.icon-add {
    background-image:url(../icons/add.png) !important;
}
.icon-anchor {
    background-image:url(../icons/anchor.png) !important;
}
.icon-application {
    background-image:url(../icons/application.png) !important;
}
.icon-application-add {
    background-image:url(../icons/application_add.png) !important;
}
.icon-application-cascade {
    background-image:url(../icons/application_cascade.png) !important;
}
.icon-application-delete {
    background-image:url(../icons/application_delete.png) !important;
}
.icon-application-double {
    background-image:url(../icons/application_double.png) !important;
}
.icon-application-edit {
    background-image:url(../icons/application_edit.png) !important;
}
.icon-application-error {
    background-image:url(../icons/application_error.png) !important;
}
.icon-application-form {
    background-image:url(../icons/application_form.png) !important;
}
.icon-application-form-add {
    background-image:url(../icons/application_form_add.png) !important;
}
.icon-application-form-delete {
    background-image:url(../icons/application_form_delete.png) !important;
}
.icon-application-form-edit {
    background-image:url(../icons/application_form_edit.png) !important;
}
.icon-application-form-magnify {
    background-image:url(../icons/application_form_magnify.png) !important;
}
.icon-application-get {
    background-image:url(../icons/application_get.png) !important;
}
.icon-application-go {
    background-image:url(../icons/application_go.png) !important;
}
.icon-application-home {
    background-image:url(../icons/application_home.png) !important;
}
.icon-application-key {
    background-image:url(../icons/application_key.png) !important;
}
.icon-application-lightning {
    background-image:url(../icons/application_lightning.png) !important;
}
.icon-application-link {
    background-image:url(../icons/application_link.png) !important;
}
.icon-application-osx {
    background-image:url(../icons/application_osx.png) !important;
}
.icon-application-osx-terminal {
    background-image:url(../icons/application_osx_terminal.png) !important;
}
.icon-application-put {
    background-image:url(../icons/application_put.png) !important;
}
.icon-application-side-boxes {
    background-image:url(../icons/application_side_boxes.png) !important;
}
.icon-application-side-contract {
    background-image:url(../icons/application_side_contract.png) !important;
}
.icon-application-side-expand {
    background-image:url(../icons/application_side_expand.png) !important;
}
.icon-application-side-list {
    background-image:url(../icons/application_side_list.png) !important;
}
.icon-application-side-tree {
    background-image:url(../icons/application_side_tree.png) !important;
}
.icon-application-split {
    background-image:url(../icons/application_split.png) !important;
}
.icon-application-tile-horizontal {
    background-image:url(../icons/application_tile_horizontal.png) !important;
}
.icon-application-tile-vertical {
    background-image:url(../icons/application_tile_vertical.png) !important;
}
.icon-application-view-columns {
    background-image:url(../icons/application_view_columns.png) !important;
}
.icon-application-view-detail {
    background-image:url(../icons/application_view_detail.png) !important;
}
.icon-application-view-gallery {
    background-image:url(../icons/application_view_gallery.png) !important;
}
.icon-application-view-icons {
    background-image:url(../icons/application_view_icons.png) !important;
}
.icon-application-view-list {
    background-image:url(../icons/application_view_list.png) !important;
}
.icon-application-view-tile {
    background-image:url(../icons/application_view_tile.png) !important;
}
.icon-application-xp {
    background-image:url(../icons/application_xp.png) !important;
}
.icon-application-xp-terminal {
    background-image:url(../icons/application_xp_terminal.png) !important;
}
.icon-arrow-branch {
    background-image:url(../icons/arrow_branch.png) !important;
}
.icon-arrow-divide {
    background-image:url(../icons/arrow_divide.png) !important;
}
.icon-arrow-down {
    background-image:url(../icons/arrow_down.png) !important;
}
.icon-arrow-in {
    background-image:url(../icons/arrow_in.png) !important;
}
.icon-arrow-inout {
    background-image:url(../icons/arrow_inout.png) !important;
}
.icon-arrow-join {
    background-image:url(../icons/arrow_join.png) !important;
}
.icon-arrow-left {
    background-image:url(../icons/arrow_left.png) !important;
}
.icon-arrow-merge {
    background-image:url(../icons/arrow_merge.png) !important;
}
.icon-arrow-out {
    background-image:url(../icons/arrow_out.png) !important;
}
.icon-arrow-redo {
    background-image:url(../icons/arrow_redo.png) !important;
}
.icon-arrow-refresh {
    background-image:url(../icons/arrow_refresh.png) !important;
}
.icon-arrow-refresh-small {
    background-image:url(../icons/arrow_refresh_small.png) !important;
}
.icon-arrow-right {
    background-image:url(../icons/arrow_right.png) !important;
}
.icon-arrow-rotate-anticlockwise {
    background-image:url(../icons/arrow_rotate_anticlockwise.png) !important;
}
.icon-arrow-rotate-clockwise {
    background-image:url(../icons/arrow_rotate_clockwise.png) !important;
}
.icon-arrow-switch {
    background-image:url(../icons/arrow_switch.png) !important;
}
.icon-arrow-turn-left {
    background-image:url(../icons/arrow_turn_left.png) !important;
}
.icon-arrow-turn-right {
    background-image:url(../icons/arrow_turn_right.png) !important;
}
.icon-arrow-undo {
    background-image:url(../icons/arrow_undo.png) !important;
}
.icon-arrow-up {
    background-image:url(../icons/arrow_up.png) !important;
}
.icon-asterisk-orange {
    background-image:url(../icons/asterisk_orange.png) !important;
}
.icon-asterisk-yellow {
    background-image:url(../icons/asterisk_yellow.png) !important;
}
.icon-attach {
    background-image:url(../icons/attach.png) !important;
}
.icon-award-star-add {
    background-image:url(../icons/award_star_add.png) !important;
}
.icon-award-star-bronze-1 {
    background-image:url(../icons/award_star_bronze_1.png) !important;
}
.icon-award-star-bronze-2 {
    background-image:url(../icons/award_star_bronze_2.png) !important;
}
.icon-award-star-bronze-3 {
    background-image:url(../icons/award_star_bronze_3.png) !important;
}
.icon-award-star-delete {
    background-image:url(../icons/award_star_delete.png) !important;
}
.icon-award-star-gold-1 {
    background-image:url(../icons/award_star_gold_1.png) !important;
}
.icon-award-star-gold-2 {
    background-image:url(../icons/award_star_gold_2.png) !important;
}
.icon-award-star-gold-3 {
    background-image:url(../icons/award_star_gold_3.png) !important;
}
.icon-award-star-silver-1 {
    background-image:url(../icons/award_star_silver_1.png) !important;
}
.icon-award-star-silver-2 {
    background-image:url(../icons/award_star_silver_2.png) !important;
}
.icon-award-star-silver-3 {
    background-image:url(../icons/award_star_silver_3.png) !important;
}
.icon-basket {
    background-image:url(../icons/basket.png) !important;
}
.icon-basket-add {
    background-image:url(../icons/basket_add.png) !important;
}
.icon-basket-delete {
    background-image:url(../icons/basket_delete.png) !important;
}
.icon-basket-edit {
    background-image:url(../icons/basket_edit.png) !important;
}
.icon-basket-error {
    background-image:url(../icons/basket_error.png) !important;
}
.icon-basket-go {
    background-image:url(../icons/basket_go.png) !important;
}
.icon-basket-put {
    background-image:url(../icons/basket_put.png) !important;
}
.icon-basket-remove {
    background-image:url(../icons/basket_remove.png) !important;
}
.icon-bell {
    background-image:url(../icons/bell.png) !important;
}
.icon-bell-add {
    background-image:url(../icons/bell_add.png) !important;
}
.icon-bell-delete {
    background-image:url(../icons/bell_delete.png) !important;
}
.icon-bell-error {
    background-image:url(../icons/bell_error.png) !important;
}
.icon-bell-go {
    background-image:url(../icons/bell_go.png) !important;
}
.icon-bell-link {
    background-image:url(../icons/bell_link.png) !important;
}
.icon-bin {
    background-image:url(../icons/bin.png) !important;
}
.icon-bin-closed {
    background-image:url(../icons/bin_closed.png) !important;
}
.icon-bin-empty {
    background-image:url(../icons/bin_empty.png) !important;
}
.icon-bomb {
    background-image:url(../icons/bomb.png) !important;
}
.icon-book {
    background-image:url(../icons/book.png) !important;
}
.icon-book-add {
    background-image:url(../icons/book_add.png) !important;
}
.icon-book-addresses {
    background-image:url(../icons/book_addresses.png) !important;
}
.icon-book-delete {
    background-image:url(../icons/book_delete.png) !important;
}
.icon-book-edit {
    background-image:url(../icons/book_edit.png) !important;
}
.icon-book-error {
    background-image:url(../icons/book_error.png) !important;
}
.icon-book-go {
    background-image:url(../icons/book_go.png) !important;
}
.icon-book-key {
    background-image:url(../icons/book_key.png) !important;
}
.icon-book-link {
    background-image:url(../icons/book_link.png) !important;
}
.icon-book-next {
    background-image:url(../icons/book_next.png) !important;
}
.icon-book-open {
    background-image:url(../icons/book_open.png) !important;
}
.icon-book-previous {
    background-image:url(../icons/book_previous.png) !important;
}
.icon-box {
    background-image:url(../icons/box.png) !important;
}
.icon-brick {
    background-image:url(../icons/brick.png) !important;
}
.icon-bricks {
    background-image:url(../icons/bricks.png) !important;
}
.icon-brick-add {
    background-image:url(../icons/brick_add.png) !important;
}
.icon-brick-delete {
    background-image:url(../icons/brick_delete.png) !important;
}
.icon-brick-edit {
    background-image:url(../icons/brick_edit.png) !important;
}
.icon-brick-error {
    background-image:url(../icons/brick_error.png) !important;
}
.icon-brick-go {
    background-image:url(../icons/brick_go.png) !important;
}
.icon-brick-link {
    background-image:url(../icons/brick_link.png) !important;
}
.icon-briefcase {
    background-image:url(../icons/briefcase.png) !important;
}
.icon-bug {
    background-image:url(../icons/bug.png) !important;
}
.icon-bug-add {
    background-image:url(../icons/bug_add.png) !important;
}
.icon-bug-delete {
    background-image:url(../icons/bug_delete.png) !important;
}
.icon-bug-edit {
    background-image:url(../icons/bug_edit.png) !important;
}
.icon-bug-error {
    background-image:url(../icons/bug_error.png) !important;
}
.icon-bug-go {
    background-image:url(../icons/bug_go.png) !important;
}
.icon-bug-link {
    background-image:url(../icons/bug_link.png) !important;
}
.icon-building {
    background-image:url(../icons/building.png) !important;
}
.icon-building-add {
    background-image:url(../icons/building_add.png) !important;
}
.icon-building-delete {
    background-image:url(../icons/building_delete.png) !important;
}
.icon-building-edit {
    background-image:url(../icons/building_edit.png) !important;
}
.icon-building-error {
    background-image:url(../icons/building_error.png) !important;
}
.icon-building-go {
    background-image:url(../icons/building_go.png) !important;
}
.icon-building-key {
    background-image:url(../icons/building_key.png) !important;
}
.icon-building-link {
    background-image:url(../icons/building_link.png) !important;
}
.icon-bullet-add {
    background-image:url(../icons/bullet_add.png) !important;
}
.icon-bullet-arrow-bottom {
    background-image:url(../icons/bullet_arrow_bottom.png) !important;
}
.icon-bullet-arrow-down {
    background-image:url(../icons/bullet_arrow_down.png) !important;
}
.icon-bullet-arrow-top {
    background-image:url(../icons/bullet_arrow_top.png) !important;
}
.icon-bullet-arrow-up {
    background-image:url(../icons/bullet_arrow_up.png) !important;
}
.icon-bullet-black {
    background-image:url(../icons/bullet_black.png) !important;
}
.icon-bullet-blue {
    background-image:url(../icons/bullet_blue.png) !important;
}
.icon-bullet-delete {
    background-image:url(../icons/bullet_delete.png) !important;
}
.icon-bullet-disk {
    background-image:url(../icons/bullet_disk.png) !important;
}
.icon-bullet-error {
    background-image:url(../icons/bullet_error.png) !important;
}
.icon-bullet-feed {
    background-image:url(../icons/bullet_feed.png) !important;
}
.icon-bullet-go {
    background-image:url(../icons/bullet_go.png) !important;
}
.icon-bullet-green {
    background-image:url(../icons/bullet_green.png) !important;
}
.icon-bullet-key {
    background-image:url(../icons/bullet_key.png) !important;
}
.icon-bullet-orange {
    background-image:url(../icons/bullet_orange.png) !important;
}
.icon-bullet-picture {
    background-image:url(../icons/bullet_picture.png) !important;
}
.icon-bullet-pink {
    background-image:url(../icons/bullet_pink.png) !important;
}
.icon-bullet-purple {
    background-image:url(../icons/bullet_purple.png) !important;
}
.icon-bullet-red {
    background-image:url(../icons/bullet_red.png) !important;
}
.icon-bullet-star {
    background-image:url(../icons/bullet_star.png) !important;
}
.icon-bullet-toggle-minus {
    background-image:url(../icons/bullet_toggle_minus.png) !important;
}
.icon-bullet-toggle-plus {
    background-image:url(../icons/bullet_toggle_plus.png) !important;
}
.icon-bullet-white {
    background-image:url(../icons/bullet_white.png) !important;
}
.icon-bullet-wrench {
    background-image:url(../icons/bullet_wrench.png) !important;
}
.icon-bullet-yellow {
    background-image:url(../icons/bullet_yellow.png) !important;
}
.icon-cake {
    background-image:url(../icons/cake.png) !important;
}
.icon-calculator {
    background-image:url(../icons/calculator.png) !important;
}
.icon-calculator-add {
    background-image:url(../icons/calculator_add.png) !important;
}
.icon-calculator-delete {
    background-image:url(../icons/calculator_delete.png) !important;
}
.icon-calculator-edit {
    background-image:url(../icons/calculator_edit.png) !important;
}
.icon-calculator-error {
    background-image:url(../icons/calculator_error.png) !important;
}
.icon-calculator-link {
    background-image:url(../icons/calculator_link.png) !important;
}
.icon-calendar {
    background-image:url(../icons/calendar.png) !important;
}
.icon-calendar-add {
    background-image:url(../icons/calendar_add.png) !important;
}
.icon-calendar-delete {
    background-image:url(../icons/calendar_delete.png) !important;
}
.icon-calendar-edit {
    background-image:url(../icons/calendar_edit.png) !important;
}
.icon-calendar-link {
    background-image:url(../icons/calendar_link.png) !important;
}
.icon-calendar-view-day {
    background-image:url(../icons/calendar_view_day.png) !important;
}
.icon-calendar-view-month {
    background-image:url(../icons/calendar_view_month.png) !important;
}
.icon-calendar-view-week {
    background-image:url(../icons/calendar_view_week.png) !important;
}
.icon-camera {
    background-image:url(../icons/camera.png) !important;
}
.icon-camera-add {
    background-image:url(../icons/camera_add.png) !important;
}
.icon-camera-delete {
    background-image:url(../icons/camera_delete.png) !important;
}
.icon-camera-edit {
    background-image:url(../icons/camera_edit.png) !important;
}
.icon-camera-error {
    background-image:url(../icons/camera_error.png) !important;
}
.icon-camera-go {
    background-image:url(../icons/camera_go.png) !important;
}
.icon-camera-link {
    background-image:url(../icons/camera_link.png) !important;
}
.icon-camera-small {
    background-image:url(../icons/camera_small.png) !important;
}
.icon-cancel {
    background-image:url(../icons/cancel.png) !important;
}
.icon-car {
    background-image:url(../icons/car.png) !important;
}
.icon-cart {
    background-image:url(../icons/cart.png) !important;
}
.icon-cart-add {
    background-image:url(../icons/cart_add.png) !important;
}
.icon-cart-delete {
    background-image:url(../icons/cart_delete.png) !important;
}
.icon-cart-edit {
    background-image:url(../icons/cart_edit.png) !important;
}
.icon-cart-error {
    background-image:url(../icons/cart_error.png) !important;
}
.icon-cart-go {
    background-image:url(../icons/cart_go.png) !important;
}
.icon-cart-put {
    background-image:url(../icons/cart_put.png) !important;
}
.icon-cart-remove {
    background-image:url(../icons/cart_remove.png) !important;
}
.icon-car-add {
    background-image:url(../icons/car_add.png) !important;
}
.icon-car-delete {
    background-image:url(../icons/car_delete.png) !important;
}
.icon-cd {
    background-image:url(../icons/cd.png) !important;
}
.icon-cd-add {
    background-image:url(../icons/cd_add.png) !important;
}
.icon-cd-burn {
    background-image:url(../icons/cd_burn.png) !important;
}
.icon-cd-delete {
    background-image:url(../icons/cd_delete.png) !important;
}
.icon-cd-edit {
    background-image:url(../icons/cd_edit.png) !important;
}
.icon-cd-eject {
    background-image:url(../icons/cd_eject.png) !important;
}
.icon-cd-go {
    background-image:url(../icons/cd_go.png) !important;
}
.icon-chart-bar {
    background-image:url(../icons/chart_bar.png) !important;
}
.icon-chart-bar-add {
    background-image:url(../icons/chart_bar_add.png) !important;
}
.icon-chart-bar-delete {
    background-image:url(../icons/chart_bar_delete.png) !important;
}
.icon-chart-bar-edit {
    background-image:url(../icons/chart_bar_edit.png) !important;
}
.icon-chart-bar-error {
    background-image:url(../icons/chart_bar_error.png) !important;
}
.icon-chart-bar-link {
    background-image:url(../icons/chart_bar_link.png) !important;
}
.icon-chart-curve {
    background-image:url(../icons/chart_curve.png) !important;
}
.icon-chart-curve-add {
    background-image:url(../icons/chart_curve_add.png) !important;
}
.icon-chart-curve-delete {
    background-image:url(../icons/chart_curve_delete.png) !important;
}
.icon-chart-curve-edit {
    background-image:url(../icons/chart_curve_edit.png) !important;
}
.icon-chart-curve-error {
    background-image:url(../icons/chart_curve_error.png) !important;
}
.icon-chart-curve-go {
    background-image:url(../icons/chart_curve_go.png) !important;
}
.icon-chart-curve-link {
    background-image:url(../icons/chart_curve_link.png) !important;
}
.icon-chart-line {
    background-image:url(../icons/chart_line.png) !important;
}
.icon-chart-line-add {
    background-image:url(../icons/chart_line_add.png) !important;
}
.icon-chart-line-delete {
    background-image:url(../icons/chart_line_delete.png) !important;
}
.icon-chart-line-edit {
    background-image:url(../icons/chart_line_edit.png) !important;
}
.icon-chart-line-error {
    background-image:url(../icons/chart_line_error.png) !important;
}
.icon-chart-line-link {
    background-image:url(../icons/chart_line_link.png) !important;
}
.icon-chart-organisation {
    background-image:url(../icons/chart_organisation.png) !important;
}
.icon-chart-organisation-add {
    background-image:url(../icons/chart_organisation_add.png) !important;
}
.icon-chart-organisation-delete {
    background-image:url(../icons/chart_organisation_delete.png) !important;
}
.icon-chart-pie {
    background-image:url(../icons/chart_pie.png) !important;
}
.icon-chart-pie-add {
    background-image:url(../icons/chart_pie_add.png) !important;
}
.icon-chart-pie-delete {
    background-image:url(../icons/chart_pie_delete.png) !important;
}
.icon-chart-pie-edit {
    background-image:url(../icons/chart_pie_edit.png) !important;
}
.icon-chart-pie-error {
    background-image:url(../icons/chart_pie_error.png) !important;
}
.icon-chart-pie-link {
    background-image:url(../icons/chart_pie_link.png) !important;
}
.icon-clock {
    background-image:url(../icons/clock.png) !important;
}
.icon-clock-add {
    background-image:url(../icons/clock_add.png) !important;
}
.icon-clock-delete {
    background-image:url(../icons/clock_delete.png) !important;
}
.icon-clock-edit {
    background-image:url(../icons/clock_edit.png) !important;
}
.icon-clock-error {
    background-image:url(../icons/clock_error.png) !important;
}
.icon-clock-go {
    background-image:url(../icons/clock_go.png) !important;
}
.icon-clock-link {
    background-image:url(../icons/clock_link.png) !important;
}
.icon-clock-pause {
    background-image:url(../icons/clock_pause.png) !important;
}
.icon-clock-play {
    background-image:url(../icons/clock_play.png) !important;
}
.icon-clock-red {
    background-image:url(../icons/clock_red.png) !important;
}
.icon-clock-stop {
    background-image:url(../icons/clock_stop.png) !important;
}
.icon-cog {
    background-image:url(../icons/cog.png) !important;
}
.icon-cog-add {
    background-image:url(../icons/cog_add.png) !important;
}
.icon-cog-delete {
    background-image:url(../icons/cog_delete.png) !important;
}
.icon-cog-edit {
    background-image:url(../icons/cog_edit.png) !important;
}
.icon-cog-error {
    background-image:url(../icons/cog_error.png) !important;
}
.icon-cog-go {
    background-image:url(../icons/cog_go.png) !important;
}
.icon-coins {
    background-image:url(../icons/coins.png) !important;
}
.icon-coins-add {
    background-image:url(../icons/coins_add.png) !important;
}
.icon-coins-delete {
    background-image:url(../icons/coins_delete.png) !important;
}
.icon-color-swatch {
    background-image:url(../icons/color_swatch.png) !important;
}
.icon-color-wheel {
    background-image:url(../icons/color_wheel.png) !important;
}
.icon-comment {
    background-image:url(../icons/comment.png) !important;
}
.icon-comments {
    background-image:url(../icons/comments.png) !important;
}
.icon-comments-add {
    background-image:url(../icons/comments_add.png) !important;
}
.icon-comments-delete {
    background-image:url(../icons/comments_delete.png) !important;
}
.icon-comment-add {
    background-image:url(../icons/comment_add.png) !important;
}
.icon-comment-delete {
    background-image:url(../icons/comment_delete.png) !important;
}
.icon-comment-edit {
    background-image:url(../icons/comment_edit.png) !important;
}
.icon-compress {
    background-image:url(../icons/compress.png) !important;
}
.icon-computer {
    background-image:url(../icons/computer.png) !important;
}
.icon-computer-add {
    background-image:url(../icons/computer_add.png) !important;
}
.icon-computer-delete {
    background-image:url(../icons/computer_delete.png) !important;
}
.icon-computer-edit {
    background-image:url(../icons/computer_edit.png) !important;
}
.icon-computer-error {
    background-image:url(../icons/computer_error.png) !important;
}
.icon-computer-go {
    background-image:url(../icons/computer_go.png) !important;
}
.icon-computer-key {
    background-image:url(../icons/computer_key.png) !important;
}
.icon-computer-link {
    background-image:url(../icons/computer_link.png) !important;
}
.icon-connect {
    background-image:url(../icons/connect.png) !important;
}
.icon-contrast {
    background-image:url(../icons/contrast.png) !important;
}
.icon-contrast-decrease {
    background-image:url(../icons/contrast_decrease.png) !important;
}
.icon-contrast-high {
    background-image:url(../icons/contrast_high.png) !important;
}
.icon-contrast-increase {
    background-image:url(../icons/contrast_increase.png) !important;
}
.icon-contrast-low {
    background-image:url(../icons/contrast_low.png) !important;
}
.icon-controller {
    background-image:url(../icons/controller.png) !important;
}
.icon-controller-add {
    background-image:url(../icons/controller_add.png) !important;
}
.icon-controller-delete {
    background-image:url(../icons/controller_delete.png) !important;
}
.icon-controller-error {
    background-image:url(../icons/controller_error.png) !important;
}
.icon-control-eject {
    background-image:url(../icons/control_eject.png) !important;
}
.icon-control-eject-blue {
    background-image:url(../icons/control_eject_blue.png) !important;
}
.icon-control-end {
    background-image:url(../icons/control_end.png) !important;
}
.icon-control-end-blue {
    background-image:url(../icons/control_end_blue.png) !important;
}
.icon-control-equalizer {
    background-image:url(../icons/control_equalizer.png) !important;
}
.icon-control-equalizer-blue {
    background-image:url(../icons/control_equalizer_blue.png) !important;
}
.icon-control-fastforward {
    background-image:url(../icons/control_fastforward.png) !important;
}
.icon-control-fastforward-blue {
    background-image:url(../icons/control_fastforward_blue.png) !important;
}
.icon-control-pause {
    background-image:url(../icons/control_pause.png) !important;
}
.icon-control-pause-blue {
    background-image:url(../icons/control_pause_blue.png) !important;
}
.icon-control-play {
    background-image:url(../icons/control_play.png) !important;
}
.icon-control-play-blue {
    background-image:url(../icons/control_play_blue.png) !important;
}
.icon-control-repeat {
    background-image:url(../icons/control_repeat.png) !important;
}
.icon-control-repeat-blue {
    background-image:url(../icons/control_repeat_blue.png) !important;
}
.icon-control-rewind {
    background-image:url(../icons/control_rewind.png) !important;
}
.icon-control-rewind-blue {
    background-image:url(../icons/control_rewind_blue.png) !important;
}
.icon-control-start {
    background-image:url(../icons/control_start.png) !important;
}
.icon-control-start-blue {
    background-image:url(../icons/control_start_blue.png) !important;
}
.icon-control-stop {
    background-image:url(../icons/control_stop.png) !important;
}
.icon-control-stop-blue {
    background-image:url(../icons/control_stop_blue.png) !important;
}
.icon-creditcards {
    background-image:url(../icons/creditcards.png) !important;
}
.icon-cross {
    background-image:url(../icons/cross.png) !important;
}
.icon-css {
    background-image:url(../icons/css.png) !important;
}
.icon-css-add {
    background-image:url(../icons/css_add.png) !important;
}
.icon-css-delete {
    background-image:url(../icons/css_delete.png) !important;
}
.icon-css-go {
    background-image:url(../icons/css_go.png) !important;
}
.icon-css-valid {
    background-image:url(../icons/css_valid.png) !important;
}
.icon-cup {
    background-image:url(../icons/cup.png) !important;
}
.icon-cup-add {
    background-image:url(../icons/cup_add.png) !important;
}
.icon-cup-delete {
    background-image:url(../icons/cup_delete.png) !important;
}
.icon-cup-edit {
    background-image:url(../icons/cup_edit.png) !important;
}
.icon-cup-error {
    background-image:url(../icons/cup_error.png) !important;
}
.icon-cup-go {
    background-image:url(../icons/cup_go.png) !important;
}
.icon-cup-key {
    background-image:url(../icons/cup_key.png) !important;
}
.icon-cup-link {
    background-image:url(../icons/cup_link.png) !important;
}
.icon-cursor {
    background-image:url(../icons/cursor.png) !important;
}
.icon-cut {
    background-image:url(../icons/cut.png) !important;
}
.icon-cut-red {
    background-image:url(../icons/cut_red.png) !important;
}
.icon-database {
    background-image:url(../icons/database.png) !important;
}
.icon-database-add {
    background-image:url(../icons/database_add.png) !important;
}
.icon-database-connect {
    background-image:url(../icons/database_connect.png) !important;
}
.icon-database-delete {
    background-image:url(../icons/database_delete.png) !important;
}
.icon-database-edit {
    background-image:url(../icons/database_edit.png) !important;
}
.icon-database-error {
    background-image:url(../icons/database_error.png) !important;
}
.icon-database-gear {
    background-image:url(../icons/database_gear.png) !important;
}
.icon-database-go {
    background-image:url(../icons/database_go.png) !important;
}
.icon-database-key {
    background-image:url(../icons/database_key.png) !important;
}
.icon-database-lightning {
    background-image:url(../icons/database_lightning.png) !important;
}
.icon-database-link {
    background-image:url(../icons/database_link.png) !important;
}
.icon-database-refresh {
    background-image:url(../icons/database_refresh.png) !important;
}
.icon-database-save {
    background-image:url(../icons/database_save.png) !important;
}
.icon-database-table {
    background-image:url(../icons/database_table.png) !important;
}
.icon-date {
    background-image:url(../icons/date.png) !important;
}
.icon-date-add {
    background-image:url(../icons/date_add.png) !important;
}
.icon-date-delete {
    background-image:url(../icons/date_delete.png) !important;
}
.icon-date-edit {
    background-image:url(../icons/date_edit.png) !important;
}
.icon-date-error {
    background-image:url(../icons/date_error.png) !important;
}
.icon-date-go {
    background-image:url(../icons/date_go.png) !important;
}
.icon-date-link {
    background-image:url(../icons/date_link.png) !important;
}
.icon-date-magnify {
    background-image:url(../icons/date_magnify.png) !important;
}
.icon-date-next {
    background-image:url(../icons/date_next.png) !important;
}
.icon-date-previous {
    background-image:url(../icons/date_previous.png) !important;
}
.icon-delete {
    background-image:url(../icons/delete.png) !important;
}
.icon-disconnect {
    background-image:url(../icons/disconnect.png) !important;
}
.icon-disk {
    background-image:url(../icons/disk.png) !important;
}
.icon-disk-multiple {
    background-image:url(../icons/disk_multiple.png) !important;
}
.icon-door {
    background-image:url(../icons/door.png) !important;
}
.icon-door-in {
    background-image:url(../icons/door_in.png) !important;
}
.icon-door-open {
    background-image:url(../icons/door_open.png) !important;
}
.icon-door-out {
    background-image:url(../icons/door_out.png) !important;
}
.icon-drink {
    background-image:url(../icons/drink.png) !important;
}
.icon-drink-empty {
    background-image:url(../icons/drink_empty.png) !important;
}
.icon-drive {
    background-image:url(../icons/drive.png) !important;
}
.icon-drive-add {
    background-image:url(../icons/drive_add.png) !important;
}
.icon-drive-burn {
    background-image:url(../icons/drive_burn.png) !important;
}
.icon-drive-cd {
    background-image:url(../icons/drive_cd.png) !important;
}
.icon-drive-cd-empty {
    background-image:url(../icons/drive_cd_empty.png) !important;
}
.icon-drive-delete {
    background-image:url(../icons/drive_delete.png) !important;
}
.icon-drive-disk {
    background-image:url(../icons/drive_disk.png) !important;
}
.icon-drive-edit {
    background-image:url(../icons/drive_edit.png) !important;
}
.icon-drive-error {
    background-image:url(../icons/drive_error.png) !important;
}
.icon-drive-go {
    background-image:url(../icons/drive_go.png) !important;
}
.icon-drive-key {
    background-image:url(../icons/drive_key.png) !important;
}
.icon-drive-link {
    background-image:url(../icons/drive_link.png) !important;
}
.icon-drive-magnify {
    background-image:url(../icons/drive_magnify.png) !important;
}
.icon-drive-network {
    background-image:url(../icons/drive_network.png) !important;
}
.icon-drive-rename {
    background-image:url(../icons/drive_rename.png) !important;
}
.icon-drive-user {
    background-image:url(../icons/drive_user.png) !important;
}
.icon-drive-web {
    background-image:url(../icons/drive_web.png) !important;
}
.icon-dvd {
    background-image:url(../icons/dvd.png) !important;
}
.icon-dvd-add {
    background-image:url(../icons/dvd_add.png) !important;
}
.icon-dvd-delete {
    background-image:url(../icons/dvd_delete.png) !important;
}
.icon-dvd-edit {
    background-image:url(../icons/dvd_edit.png) !important;
}
.icon-dvd-error {
    background-image:url(../icons/dvd_error.png) !important;
}
.icon-dvd-go {
    background-image:url(../icons/dvd_go.png) !important;
}
.icon-dvd-key {
    background-image:url(../icons/dvd_key.png) !important;
}
.icon-dvd-link {
    background-image:url(../icons/dvd_link.png) !important;
}
.icon-email {
    background-image:url(../icons/email.png) !important;
}
.icon-email-add {
    background-image:url(../icons/email_add.png) !important;
}
.icon-email-attach {
    background-image:url(../icons/email_attach.png) !important;
}
.icon-email-delete {
    background-image:url(../icons/email_delete.png) !important;
}
.icon-email-edit {
    background-image:url(../icons/email_edit.png) !important;
}
.icon-email-error {
    background-image:url(../icons/email_error.png) !important;
}
.icon-email-go {
    background-image:url(../icons/email_go.png) !important;
}
.icon-email-link {
    background-image:url(../icons/email_link.png) !important;
}
.icon-email-open {
    background-image:url(../icons/email_open.png) !important;
}
.icon-email-open-image {
    background-image:url(../icons/email_open_image.png) !important;
}
.icon-emoticon-evilgrin {
    background-image:url(../icons/emoticon_evilgrin.png) !important;
}
.icon-emoticon-grin {
    background-image:url(../icons/emoticon_grin.png) !important;
}
.icon-emoticon-happy {
    background-image:url(../icons/emoticon_happy.png) !important;
}
.icon-emoticon-smile {
    background-image:url(../icons/emoticon_smile.png) !important;
}
.icon-emoticon-surprised {
    background-image:url(../icons/emoticon_surprised.png) !important;
}
.icon-emoticon-tongue {
    background-image:url(../icons/emoticon_tongue.png) !important;
}
.icon-emoticon-unhappy {
    background-image:url(../icons/emoticon_unhappy.png) !important;
}
.icon-emoticon-waii {
    background-image:url(../icons/emoticon_waii.png) !important;
}
.icon-emoticon-wink {
    background-image:url(../icons/emoticon_wink.png) !important;
}
.icon-error {
    background-image:url(../icons/error.png) !important;
}
.icon-error-add {
    background-image:url(../icons/error_add.png) !important;
}
.icon-error-delete {
    background-image:url(../icons/error_delete.png) !important;
}
.icon-error-go {
    background-image:url(../icons/error_go.png) !important;
}
.icon-exclamation {
    background-image:url(../icons/exclamation.png) !important;
}
.icon-eye {
    background-image:url(../icons/eye.png) !important;
}
.icon-feed {
    background-image:url(../icons/feed.png) !important;
}
.icon-feed-add {
    background-image:url(../icons/feed_add.png) !important;
}
.icon-feed-delete {
    background-image:url(../icons/feed_delete.png) !important;
}
.icon-feed-disk {
    background-image:url(../icons/feed_disk.png) !important;
}
.icon-feed-edit {
    background-image:url(../icons/feed_edit.png) !important;
}
.icon-feed-error {
    background-image:url(../icons/feed_error.png) !important;
}
.icon-feed-go {
    background-image:url(../icons/feed_go.png) !important;
}
.icon-feed-key {
    background-image:url(../icons/feed_key.png) !important;
}
.icon-feed-link {
    background-image:url(../icons/feed_link.png) !important;
}
.icon-feed-magnify {
    background-image:url(../icons/feed_magnify.png) !important;
}
.icon-female {
    background-image:url(../icons/female.png) !important;
}
.icon-film {
    background-image:url(../icons/film.png) !important;
}
.icon-film-add {
    background-image:url(../icons/film_add.png) !important;
}
.icon-film-delete {
    background-image:url(../icons/film_delete.png) !important;
}
.icon-film-edit {
    background-image:url(../icons/film_edit.png) !important;
}
.icon-film-error {
    background-image:url(../icons/film_error.png) !important;
}
.icon-film-go {
    background-image:url(../icons/film_go.png) !important;
}
.icon-film-key {
    background-image:url(../icons/film_key.png) !important;
}
.icon-film-link {
    background-image:url(../icons/film_link.png) !important;
}
.icon-film-save {
    background-image:url(../icons/film_save.png) !important;
}
.icon-find {
    background-image:url(../icons/find.png) !important;
}
.icon-flag-blue {
    background-image:url(../icons/flag_blue.png) !important;
}
.icon-flag-green {
    background-image:url(../icons/flag_green.png) !important;
}
.icon-flag-orange {
    background-image:url(../icons/flag_orange.png) !important;
}
.icon-flag-pink {
    background-image:url(../icons/flag_pink.png) !important;
}
.icon-flag-purple {
    background-image:url(../icons/flag_purple.png) !important;
}
.icon-flag-red {
    background-image:url(../icons/flag_red.png) !important;
}
.icon-flag-yellow {
    background-image:url(../icons/flag_yellow.png) !important;
}
.icon-folder {
    background-image:url(../icons/folder.png) !important;
}
.icon-folder-add {
    background-image:url(../icons/folder_add.png) !important;
}
.icon-folder-bell {
    background-image:url(../icons/folder_bell.png) !important;
}
.icon-folder-brick {
    background-image:url(../icons/folder_brick.png) !important;
}
.icon-folder-bug {
    background-image:url(../icons/folder_bug.png) !important;
}
.icon-folder-camera {
    background-image:url(../icons/folder_camera.png) !important;
}
.icon-folder-database {
    background-image:url(../icons/folder_database.png) !important;
}
.icon-folder-delete {
    background-image:url(../icons/folder_delete.png) !important;
}
.icon-folder-edit {
    background-image:url(../icons/folder_edit.png) !important;
}
.icon-folder-error {
    background-image:url(../icons/folder_error.png) !important;
}
.icon-folder-explore {
    background-image:url(../icons/folder_explore.png) !important;
}
.icon-folder-feed {
    background-image:url(../icons/folder_feed.png) !important;
}
.icon-folder-find {
    background-image:url(../icons/folder_find.png) !important;
}
.icon-folder-go {
    background-image:url(../icons/folder_go.png) !important;
}
.icon-folder-heart {
    background-image:url(../icons/folder_heart.png) !important;
}
.icon-folder-image {
    background-image:url(../icons/folder_image.png) !important;
}
.icon-folder-key {
    background-image:url(../icons/folder_key.png) !important;
}
.icon-folder-lightbulb {
    background-image:url(../icons/folder_lightbulb.png) !important;
}
.icon-folder-link {
    background-image:url(../icons/folder_link.png) !important;
}
.icon-folder-magnify {
    background-image:url(../icons/folder_magnify.png) !important;
}
.icon-folder-page {
    background-image:url(../icons/folder_page.png) !important;
}
.icon-folder-page-white {
    background-image:url(../icons/folder_page_white.png) !important;
}
.icon-folder-palette {
    background-image:url(../icons/folder_palette.png) !important;
}
.icon-folder-picture {
    background-image:url(../icons/folder_picture.png) !important;
}
.icon-folder-star {
    background-image:url(../icons/folder_star.png) !important;
}
.icon-folder-table {
    background-image:url(../icons/folder_table.png) !important;
}
.icon-folder-user {
    background-image:url(../icons/folder_user.png) !important;
}
.icon-folder-wrench {
    background-image:url(../icons/folder_wrench.png) !important;
}
.icon-font {
    background-image:url(../icons/font.png) !important;
}
.icon-font-add {
    background-image:url(../icons/font_add.png) !important;
}
.icon-font-delete {
    background-image:url(../icons/font_delete.png) !important;
}
.icon-font-go {
    background-image:url(../icons/font_go.png) !important;
}
.icon-group {
    background-image:url(../icons/group.png) !important;
}
.icon-group-add {
    background-image:url(../icons/group_add.png) !important;
}
.icon-group-delete {
    background-image:url(../icons/group_delete.png) !important;
}
.icon-group-edit {
    background-image:url(../icons/group_edit.png) !important;
}
.icon-group-error {
    background-image:url(../icons/group_error.png) !important;
}
.icon-group-gear {
    background-image:url(../icons/group_gear.png) !important;
}
.icon-group-go {
    background-image:url(../icons/group_go.png) !important;
}
.icon-group-key {
    background-image:url(../icons/group_key.png) !important;
}
.icon-group-link {
    background-image:url(../icons/group_link.png) !important;
}
.icon-heart {
    background-image:url(../icons/heart.png) !important;
}
.icon-heart-add {
    background-image:url(../icons/heart_add.png) !important;
}
.icon-heart-delete {
    background-image:url(../icons/heart_delete.png) !important;
}
.icon-help {
    background-image:url(../icons/help.png) !important;
}
.icon-hourglass {
    background-image:url(../icons/hourglass.png) !important;
}
.icon-hourglass-add {
    background-image:url(../icons/hourglass_add.png) !important;
}
.icon-hourglass-delete {
    background-image:url(../icons/hourglass_delete.png) !important;
}
.icon-hourglass-go {
    background-image:url(../icons/hourglass_go.png) !important;
}
.icon-hourglass-link {
    background-image:url(../icons/hourglass_link.png) !important;
}
.icon-house {
    background-image:url(../icons/house.png) !important;
}
.icon-house-go {
    background-image:url(../icons/house_go.png) !important;
}
.icon-house-link {
    background-image:url(../icons/house_link.png) !important;
}
.icon-html {
    background-image:url(../icons/html.png) !important;
}
.icon-html-add {
    background-image:url(../icons/html_add.png) !important;
}
.icon-html-delete {
    background-image:url(../icons/html_delete.png) !important;
}
.icon-html-go {
    background-image:url(../icons/html_go.png) !important;
}
.icon-html-valid {
    background-image:url(../icons/html_valid.png) !important;
}
.icon-image {
    background-image:url(../icons/image.png) !important;
}
.icon-images {
    background-image:url(../icons/images.png) !important;
}
.icon-image-add {
    background-image:url(../icons/image_add.png) !important;
}
.icon-image-delete {
    background-image:url(../icons/image_delete.png) !important;
}
.icon-image-edit {
    background-image:url(../icons/image_edit.png) !important;
}
.icon-image-link {
    background-image:url(../icons/image_link.png) !important;
}
.icon-information {
    background-image:url(../icons/information.png) !important;
}
.icon-ipod {
    background-image:url(../icons/ipod.png) !important;
}
.icon-ipod-cast {
    background-image:url(../icons/ipod_cast.png) !important;
}
.icon-ipod-cast-add {
    background-image:url(../icons/ipod_cast_add.png) !important;
}
.icon-ipod-cast-delete {
    background-image:url(../icons/ipod_cast_delete.png) !important;
}
.icon-ipod-sound {
    background-image:url(../icons/ipod_sound.png) !important;
}
.icon-joystick {
    background-image:url(../icons/joystick.png) !important;
}
.icon-joystick-add {
    background-image:url(../icons/joystick_add.png) !important;
}
.icon-joystick-delete {
    background-image:url(../icons/joystick_delete.png) !important;
}
.icon-joystick-error {
    background-image:url(../icons/joystick_error.png) !important;
}
.icon-key {
    background-image:url(../icons/key.png) !important;
}
.icon-keyboard {
    background-image:url(../icons/keyboard.png) !important;
}
.icon-keyboard-add {
    background-image:url(../icons/keyboard_add.png) !important;
}
.icon-keyboard-delete {
    background-image:url(../icons/keyboard_delete.png) !important;
}
.icon-keyboard-magnify {
    background-image:url(../icons/keyboard_magnify.png) !important;
}
.icon-key-add {
    background-image:url(../icons/key_add.png) !important;
}
.icon-key-delete {
    background-image:url(../icons/key_delete.png) !important;
}
.icon-key-go {
    background-image:url(../icons/key_go.png) !important;
}
.icon-layers {
    background-image:url(../icons/layers.png) !important;
}
.icon-layout {
    background-image:url(../icons/layout.png) !important;
}
.icon-layout-add {
    background-image:url(../icons/layout_add.png) !important;
}
.icon-layout-content {
    background-image:url(../icons/layout_content.png) !important;
}
.icon-layout-delete {
    background-image:url(../icons/layout_delete.png) !important;
}
.icon-layout-edit {
    background-image:url(../icons/layout_edit.png) !important;
}
.icon-layout-error {
    background-image:url(../icons/layout_error.png) !important;
}
.icon-layout-header {
    background-image:url(../icons/layout_header.png) !important;
}
.icon-layout-link {
    background-image:url(../icons/layout_link.png) !important;
}
.icon-layout-sidebar {
    background-image:url(../icons/layout_sidebar.png) !important;
}
.icon-lightbulb {
    background-image:url(../icons/lightbulb.png) !important;
}
.icon-lightbulb-add {
    background-image:url(../icons/lightbulb_add.png) !important;
}
.icon-lightbulb-delete {
    background-image:url(../icons/lightbulb_delete.png) !important;
}
.icon-lightbulb-off {
    background-image:url(../icons/lightbulb_off.png) !important;
}
.icon-lightning {
    background-image:url(../icons/lightning.png) !important;
}
.icon-lightning-add {
    background-image:url(../icons/lightning_add.png) !important;
}
.icon-lightning-delete {
    background-image:url(../icons/lightning_delete.png) !important;
}
.icon-lightning-go {
    background-image:url(../icons/lightning_go.png) !important;
}
.icon-link {
    background-image:url(../icons/link.png) !important;
}
.icon-link-add {
    background-image:url(../icons/link_add.png) !important;
}
.icon-link-break {
    background-image:url(../icons/link_break.png) !important;
}
.icon-link-delete {
    background-image:url(../icons/link_delete.png) !important;
}
.icon-link-edit {
    background-image:url(../icons/link_edit.png) !important;
}
.icon-link-error {
    background-image:url(../icons/link_error.png) !important;
}
.icon-link-go {
    background-image:url(../icons/link_go.png) !important;
}
.icon-lock {
    background-image:url(../icons/lock.png) !important;
}
.icon-lock-add {
    background-image:url(../icons/lock_add.png) !important;
}
.icon-lock-break {
    background-image:url(../icons/lock_break.png) !important;
}
.icon-lock-delete {
    background-image:url(../icons/lock_delete.png) !important;
}
.icon-lock-edit {
    background-image:url(../icons/lock_edit.png) !important;
}
.icon-lock-go {
    background-image:url(../icons/lock_go.png) !important;
}
.icon-lock-open {
    background-image:url(../icons/lock_open.png) !important;
}
.icon-lorry {
    background-image:url(../icons/lorry.png) !important;
}
.icon-lorry-add {
    background-image:url(../icons/lorry_add.png) !important;
}
.icon-lorry-delete {
    background-image:url(../icons/lorry_delete.png) !important;
}
.icon-lorry-error {
    background-image:url(../icons/lorry_error.png) !important;
}
.icon-lorry-flatbed {
    background-image:url(../icons/lorry_flatbed.png) !important;
}
.icon-lorry-go {
    background-image:url(../icons/lorry_go.png) !important;
}
.icon-lorry-link {
    background-image:url(../icons/lorry_link.png) !important;
}
.icon-magifier-zoom-out {
    background-image:url(../icons/magifier_zoom_out.png) !important;
}
.icon-magnifier {
    background-image:url(../icons/magnifier.png) !important;
}
.icon-magnifier-zoom-in {
    background-image:url(../icons/magnifier_zoom_in.png) !important;
}
.icon-male {
    background-image:url(../icons/male.png) !important;
}
.icon-map {
    background-image:url(../icons/map.png) !important;
}
.icon-map-add {
    background-image:url(../icons/map_add.png) !important;
}
.icon-map-delete {
    background-image:url(../icons/map_delete.png) !important;
}
.icon-map-edit {
    background-image:url(../icons/map_edit.png) !important;
}
.icon-map-go {
    background-image:url(../icons/map_go.png) !important;
}
.icon-map-magnify {
    background-image:url(../icons/map_magnify.png) !important;
}
.icon-medal-bronze-1 {
    background-image:url(../icons/medal_bronze_1.png) !important;
}
.icon-medal-bronze-2 {
    background-image:url(../icons/medal_bronze_2.png) !important;
}
.icon-medal-bronze-3 {
    background-image:url(../icons/medal_bronze_3.png) !important;
}
.icon-medal-bronze-add {
    background-image:url(../icons/medal_bronze_add.png) !important;
}
.icon-medal-bronze-delete {
    background-image:url(../icons/medal_bronze_delete.png) !important;
}
.icon-medal-gold-1 {
    background-image:url(../icons/medal_gold_1.png) !important;
}
.icon-medal-gold-2 {
    background-image:url(../icons/medal_gold_2.png) !important;
}
.icon-medal-gold-3 {
    background-image:url(../icons/medal_gold_3.png) !important;
}
.icon-medal-gold-add {
    background-image:url(../icons/medal_gold_add.png) !important;
}
.icon-medal-gold-delete {
    background-image:url(../icons/medal_gold_delete.png) !important;
}
.icon-medal-silver-1 {
    background-image:url(../icons/medal_silver_1.png) !important;
}
.icon-medal-silver-2 {
    background-image:url(../icons/medal_silver_2.png) !important;
}
.icon-medal-silver-3 {
    background-image:url(../icons/medal_silver_3.png) !important;
}
.icon-medal-silver-add {
    background-image:url(../icons/medal_silver_add.png) !important;
}
.icon-medal-silver-delete {
    background-image:url(../icons/medal_silver_delete.png) !important;
}
.icon-money {
    background-image:url(../icons/money.png) !important;
}
.icon-money-add {
    background-image:url(../icons/money_add.png) !important;
}
.icon-money-delete {
    background-image:url(../icons/money_delete.png) !important;
}
.icon-money-dollar {
    background-image:url(../icons/money_dollar.png) !important;
}
.icon-money-euro {
    background-image:url(../icons/money_euro.png) !important;
}
.icon-money-pound {
    background-image:url(../icons/money_pound.png) !important;
}
.icon-money-yen {
    background-image:url(../icons/money_yen.png) !important;
}
.icon-monitor {
    background-image:url(../icons/monitor.png) !important;
}
.icon-monitor-add {
    background-image:url(../icons/monitor_add.png) !important;
}
.icon-monitor-delete {
    background-image:url(../icons/monitor_delete.png) !important;
}
.icon-monitor-edit {
    background-image:url(../icons/monitor_edit.png) !important;
}
.icon-monitor-error {
    background-image:url(../icons/monitor_error.png) !important;
}
.icon-monitor-go {
    background-image:url(../icons/monitor_go.png) !important;
}
.icon-monitor-lightning {
    background-image:url(../icons/monitor_lightning.png) !important;
}
.icon-monitor-link {
    background-image:url(../icons/monitor_link.png) !important;
}
.icon-mouse {
    background-image:url(../icons/mouse.png) !important;
}
.icon-mouse-add {
    background-image:url(../icons/mouse_add.png) !important;
}
.icon-mouse-delete {
    background-image:url(../icons/mouse_delete.png) !important;
}
.icon-mouse-error {
    background-image:url(../icons/mouse_error.png) !important;
}
.icon-music {
    background-image:url(../icons/music.png) !important;
}
.icon-new {
    background-image:url(../icons/new.png) !important;
}
.icon-newspaper {
    background-image:url(../icons/newspaper.png) !important;
}
.icon-newspaper-add {
    background-image:url(../icons/newspaper_add.png) !important;
}
.icon-newspaper-delete {
    background-image:url(../icons/newspaper_delete.png) !important;
}
.icon-newspaper-go {
    background-image:url(../icons/newspaper_go.png) !important;
}
.icon-newspaper-link {
    background-image:url(../icons/newspaper_link.png) !important;
}
.icon-note {
    background-image:url(../icons/note.png) !important;
}
.icon-note-add {
    background-image:url(../icons/note_add.png) !important;
}
.icon-note-delete {
    background-image:url(../icons/note_delete.png) !important;
}
.icon-note-edit {
    background-image:url(../icons/note_edit.png) !important;
}
.icon-note-error {
    background-image:url(../icons/note_error.png) !important;
}
.icon-note-go {
    background-image:url(../icons/note_go.png) !important;
}
.icon-overlays {
    background-image:url(../icons/overlays.png) !important;
}
.icon-package {
    background-image:url(../icons/package.png) !important;
}
.icon-package-add {
    background-image:url(../icons/package_add.png) !important;
}
.icon-package-delete {
    background-image:url(../icons/package_delete.png) !important;
}
.icon-package-go {
    background-image:url(../icons/package_go.png) !important;
}
.icon-package-green {
    background-image:url(../icons/package_green.png) !important;
}
.icon-package-link {
    background-image:url(../icons/package_link.png) !important;
}
.icon-page {
    background-image:url(../icons/page.png) !important;
}
.icon-page-add {
    background-image:url(../icons/page_add.png) !important;
}
.icon-page-attach {
    background-image:url(../icons/page_attach.png) !important;
}
.icon-page-code {
    background-image:url(../icons/page_code.png) !important;
}
.icon-page-copy {
    background-image:url(../icons/page_copy.png) !important;
}
.icon-page-delete {
    background-image:url(../icons/page_delete.png) !important;
}
.icon-page-edit {
    background-image:url(../icons/page_edit.png) !important;
}
.icon-page-error {
    background-image:url(../icons/page_error.png) !important;
}
.icon-page-excel {
    background-image:url(../icons/page_excel.png) !important;
}
.icon-page-find {
    background-image:url(../icons/page_find.png) !important;
}
.icon-page-gear {
    background-image:url(../icons/page_gear.png) !important;
}
.icon-page-go {
    background-image:url(../icons/page_go.png) !important;
}
.icon-page-green {
    background-image:url(../icons/page_green.png) !important;
}
.icon-page-key {
    background-image:url(../icons/page_key.png) !important;
}
.icon-page-lightning {
    background-image:url(../icons/page_lightning.png) !important;
}
.icon-page-link {
    background-image:url(../icons/page_link.png) !important;
}
.icon-page-paintbrush {
    background-image:url(../icons/page_paintbrush.png) !important;
}
.icon-page-paste {
    background-image:url(../icons/page_paste.png) !important;
}
.icon-page-red {
    background-image:url(../icons/page_red.png) !important;
}
.icon-page-refresh {
    background-image:url(../icons/page_refresh.png) !important;
}
.icon-page-save {
    background-image:url(../icons/page_save.png) !important;
}
.icon-page-white {
    background-image:url(../icons/page_white.png) !important;
}
.icon-page-white-acrobat {
    background-image:url(../icons/page_white_acrobat.png) !important;
}
.icon-page-white-actionscript {
    background-image:url(../icons/page_white_actionscript.png) !important;
}
.icon-page-white-add {
    background-image:url(../icons/page_white_add.png) !important;
}
.icon-page-white-c {
    background-image:url(../icons/page_white_c.png) !important;
}
.icon-page-white-camera {
    background-image:url(../icons/page_white_camera.png) !important;
}
.icon-page-white-cd {
    background-image:url(../icons/page_white_cd.png) !important;
}
.icon-page-white-code {
    background-image:url(../icons/page_white_code.png) !important;
}
.icon-page-white-code-red {
    background-image:url(../icons/page_white_code_red.png) !important;
}
.icon-page-white-coldfusion {
    background-image:url(../icons/page_white_coldfusion.png) !important;
}
.icon-page-white-compressed {
    background-image:url(../icons/page_white_compressed.png) !important;
}
.icon-page-white-copy {
    background-image:url(../icons/page_white_copy.png) !important;
}
.icon-page-white-cplusplus {
    background-image:url(../icons/page_white_cplusplus.png) !important;
}
.icon-page-white-csharp {
    background-image:url(../icons/page_white_csharp.png) !important;
}
.icon-page-white-cup {
    background-image:url(../icons/page_white_cup.png) !important;
}
.icon-page-white-database {
    background-image:url(../icons/page_white_database.png) !important;
}
.icon-page-white-delete {
    background-image:url(../icons/page_white_delete.png) !important;
}
.icon-page-white-dvd {
    background-image:url(../icons/page_white_dvd.png) !important;
}
.icon-page-white-edit {
    background-image:url(../icons/page_white_edit.png) !important;
}
.icon-page-white-error {
    background-image:url(../icons/page_white_error.png) !important;
}
.icon-page-white-excel {
    background-image:url(../icons/page_white_excel.png) !important;
}
.icon-page-white-find {
    background-image:url(../icons/page_white_find.png) !important;
}
.icon-page-white-flash {
    background-image:url(../icons/page_white_flash.png) !important;
}
.icon-page-white-freehand {
    background-image:url(../icons/page_white_freehand.png) !important;
}
.icon-page-white-gear {
    background-image:url(../icons/page_white_gear.png) !important;
}
.icon-page-white-get {
    background-image:url(../icons/page_white_get.png) !important;
}
.icon-page-white-go {
    background-image:url(../icons/page_white_go.png) !important;
}
.icon-page-white-h {
    background-image:url(../icons/page_white_h.png) !important;
}
.icon-page-white-horizontal {
    background-image:url(../icons/page_white_horizontal.png) !important;
}
.icon-page-white-key {
    background-image:url(../icons/page_white_key.png) !important;
}
.icon-page-white-lightning {
    background-image:url(../icons/page_white_lightning.png) !important;
}
.icon-page-white-link {
    background-image:url(../icons/page_white_link.png) !important;
}
.icon-page-white-magnify {
    background-image:url(../icons/page_white_magnify.png) !important;
}
.icon-page-white-medal {
    background-image:url(../icons/page_white_medal.png) !important;
}
.icon-page-white-office {
    background-image:url(../icons/page_white_office.png) !important;
}
.icon-page-white-paint {
    background-image:url(../icons/page_white_paint.png) !important;
}
.icon-page-white-paintbrush {
    background-image:url(../icons/page_white_paintbrush.png) !important;
}
.icon-page-white-paste {
    background-image:url(../icons/page_white_paste.png) !important;
}
.icon-page-white-php {
    background-image:url(../icons/page_white_php.png) !important;
}
.icon-page-white-picture {
    background-image:url(../icons/page_white_picture.png) !important;
}
.icon-page-white-powerpoint {
    background-image:url(../icons/page_white_powerpoint.png) !important;
}
.icon-page-white-put {
    background-image:url(../icons/page_white_put.png) !important;
}
.icon-page-white-ruby {
    background-image:url(../icons/page_white_ruby.png) !important;
}
.icon-page-white-stack {
    background-image:url(../icons/page_white_stack.png) !important;
}
.icon-page-white-star {
    background-image:url(../icons/page_white_star.png) !important;
}
.icon-page-white-swoosh {
    background-image:url(../icons/page_white_swoosh.png) !important;
}
.icon-page-white-text {
    background-image:url(../icons/page_white_text.png) !important;
}
.icon-page-white-text-width {
    background-image:url(../icons/page_white_text_width.png) !important;
}
.icon-page-white-tux {
    background-image:url(../icons/page_white_tux.png) !important;
}
.icon-page-white-vector {
    background-image:url(../icons/page_white_vector.png) !important;
}
.icon-page-white-visualstudio {
    background-image:url(../icons/page_white_visualstudio.png) !important;
}
.icon-page-white-width {
    background-image:url(../icons/page_white_width.png) !important;
}
.icon-page-white-word {
    background-image:url(../icons/page_white_word.png) !important;
}
.icon-page-white-world {
    background-image:url(../icons/page_white_world.png) !important;
}
.icon-page-white-wrench {
    background-image:url(../icons/page_white_wrench.png) !important;
}
.icon-page-white-zip {
    background-image:url(../icons/page_white_zip.png) !important;
}
.icon-page-word {
    background-image:url(../icons/page_word.png) !important;
}
.icon-page-world {
    background-image:url(../icons/page_world.png) !important;
}
.icon-paintbrush {
    background-image:url(../icons/paintbrush.png) !important;
}
.icon-paintcan {
    background-image:url(../icons/paintcan.png) !important;
}
.icon-palette {
    background-image:url(../icons/palette.png) !important;
}
.icon-paste-plain {
    background-image:url(../icons/paste_plain.png) !important;
}
.icon-paste-word {
    background-image:url(../icons/paste_word.png) !important;
}
.icon-pencil {
    background-image:url(../icons/pencil.png) !important;
}
.icon-pencil-add {
    background-image:url(../icons/pencil_add.png) !important;
}
.icon-pencil-delete {
    background-image:url(../icons/pencil_delete.png) !important;
}
.icon-pencil-go {
    background-image:url(../icons/pencil_go.png) !important;
}
.icon-phone {
    background-image:url(../icons/phone.png) !important;
}
.icon-phone-add {
    background-image:url(../icons/phone_add.png) !important;
}
.icon-phone-delete {
    background-image:url(../icons/phone_delete.png) !important;
}
.icon-phone-sound {
    background-image:url(../icons/phone_sound.png) !important;
}
.icon-photo {
    background-image:url(../icons/photo.png) !important;
}
.icon-photos {
    background-image:url(../icons/photos.png) !important;
}
.icon-photo-add {
    background-image:url(../icons/photo_add.png) !important;
}
.icon-photo-delete {
    background-image:url(../icons/photo_delete.png) !important;
}
.icon-photo-link {
    background-image:url(../icons/photo_link.png) !important;
}
.icon-picture {
    background-image:url(../icons/picture.png) !important;
}
.icon-pictures {
    background-image:url(../icons/pictures.png) !important;
}
.icon-picture-add {
    background-image:url(../icons/picture_add.png) !important;
}
.icon-picture-delete {
    background-image:url(../icons/picture_delete.png) !important;
}
.icon-picture-edit {
    background-image:url(../icons/picture_edit.png) !important;
}
.icon-picture-empty {
    background-image:url(../icons/picture_empty.png) !important;
}
.icon-picture-error {
    background-image:url(../icons/picture_error.png) !important;
}
.icon-picture-go {
    background-image:url(../icons/picture_go.png) !important;
}
.icon-picture-key {
    background-image:url(../icons/picture_key.png) !important;
}
.icon-picture-link {
    background-image:url(../icons/picture_link.png) !important;
}
.icon-picture-save {
    background-image:url(../icons/picture_save.png) !important;
}
.icon-pilcrow {
    background-image:url(../icons/pilcrow.png) !important;
}
.icon-pill {
    background-image:url(../icons/pill.png) !important;
}
.icon-pill-add {
    background-image:url(../icons/pill_add.png) !important;
}
.icon-pill-delete {
    background-image:url(../icons/pill_delete.png) !important;
}
.icon-pill-go {
    background-image:url(../icons/pill_go.png) !important;
}
.icon-plugin {
    background-image:url(../icons/plugin.png) !important;
}
.icon-plugin-add {
    background-image:url(../icons/plugin_add.png) !important;
}
.icon-plugin-delete {
    background-image:url(../icons/plugin_delete.png) !important;
}
.icon-plugin-disabled {
    background-image:url(../icons/plugin_disabled.png) !important;
}
.icon-plugin-edit {
    background-image:url(../icons/plugin_edit.png) !important;
}
.icon-plugin-error {
    background-image:url(../icons/plugin_error.png) !important;
}
.icon-plugin-go {
    background-image:url(../icons/plugin_go.png) !important;
}
.icon-plugin-link {
    background-image:url(../icons/plugin_link.png) !important;
}
.icon-printer {
    background-image:url(../icons/printer.png) !important;
}
.icon-printer-add {
    background-image:url(../icons/printer_add.png) !important;
}
.icon-printer-delete {
    background-image:url(../icons/printer_delete.png) !important;
}
.icon-printer-empty {
    background-image:url(../icons/printer_empty.png) !important;
}
.icon-printer-error {
    background-image:url(../icons/printer_error.png) !important;
}
.icon-rainbow {
    background-image:url(../icons/rainbow.png) !important;
}
.icon-report {
    background-image:url(../icons/report.png) !important;
}
.icon-report-add {
    background-image:url(../icons/report_add.png) !important;
}
.icon-report-delete {
    background-image:url(../icons/report_delete.png) !important;
}
.icon-report-disk {
    background-image:url(../icons/report_disk.png) !important;
}
.icon-report-edit {
    background-image:url(../icons/report_edit.png) !important;
}
.icon-report-go {
    background-image:url(../icons/report_go.png) !important;
}
.icon-report-key {
    background-image:url(../icons/report_key.png) !important;
}
.icon-report-link {
    background-image:url(../icons/report_link.png) !important;
}
.icon-report-magnify {
    background-image:url(../icons/report_magnify.png) !important;
}
.icon-report-picture {
    background-image:url(../icons/report_picture.png) !important;
}
.icon-report-user {
    background-image:url(../icons/report_user.png) !important;
}
.icon-report-word {
    background-image:url(../icons/report_word.png) !important;
}
.icon-resultset-first {
    background-image:url(../icons/resultset_first.png) !important;
}
.icon-resultset-last {
    background-image:url(../icons/resultset_last.png) !important;
}
.icon-resultset-next {
    background-image:url(../icons/resultset_next.png) !important;
}
.icon-resultset-previous {
    background-image:url(../icons/resultset_previous.png) !important;
}
.icon-rosette {
    background-image:url(../icons/rosette.png) !important;
}
.icon-rss {
    background-image:url(../icons/rss.png) !important;
}
.icon-rss-add {
    background-image:url(../icons/rss_add.png) !important;
}
.icon-rss-delete {
    background-image:url(../icons/rss_delete.png) !important;
}
.icon-rss-go {
    background-image:url(../icons/rss_go.png) !important;
}
.icon-rss-valid {
    background-image:url(../icons/rss_valid.png) !important;
}
.icon-ruby {
    background-image:url(../icons/ruby.png) !important;
}
.icon-ruby-add {
    background-image:url(../icons/ruby_add.png) !important;
}
.icon-ruby-delete {
    background-image:url(../icons/ruby_delete.png) !important;
}
.icon-ruby-gear {
    background-image:url(../icons/ruby_gear.png) !important;
}
.icon-ruby-get {
    background-image:url(../icons/ruby_get.png) !important;
}
.icon-ruby-go {
    background-image:url(../icons/ruby_go.png) !important;
}
.icon-ruby-key {
    background-image:url(../icons/ruby_key.png) !important;
}
.icon-ruby-link {
    background-image:url(../icons/ruby_link.png) !important;
}
.icon-ruby-put {
    background-image:url(../icons/ruby_put.png) !important;
}
.icon-script {
    background-image:url(../icons/script.png) !important;
}
.icon-script-add {
    background-image:url(../icons/script_add.png) !important;
}
.icon-script-code {
    background-image:url(../icons/script_code.png) !important;
}
.icon-script-code-red {
    background-image:url(../icons/script_code_red.png) !important;
}
.icon-script-delete {
    background-image:url(../icons/script_delete.png) !important;
}
.icon-script-edit {
    background-image:url(../icons/script_edit.png) !important;
}
.icon-script-error {
    background-image:url(../icons/script_error.png) !important;
}
.icon-script-gear {
    background-image:url(../icons/script_gear.png) !important;
}
.icon-script-go {
    background-image:url(../icons/script_go.png) !important;
}
.icon-script-key {
    background-image:url(../icons/script_key.png) !important;
}
.icon-script-lightning {
    background-image:url(../icons/script_lightning.png) !important;
}
.icon-script-link {
    background-image:url(../icons/script_link.png) !important;
}
.icon-script-palette {
    background-image:url(../icons/script_palette.png) !important;
}
.icon-script-save {
    background-image:url(../icons/script_save.png) !important;
}
.icon-server {
    background-image:url(../icons/server.png) !important;
}
.icon-server-add {
    background-image:url(../icons/server_add.png) !important;
}
.icon-server-chart {
    background-image:url(../icons/server_chart.png) !important;
}
.icon-server-compressed {
    background-image:url(../icons/server_compressed.png) !important;
}
.icon-server-connect {
    background-image:url(../icons/server_connect.png) !important;
}
.icon-server-database {
    background-image:url(../icons/server_database.png) !important;
}
.icon-server-delete {
    background-image:url(../icons/server_delete.png) !important;
}
.icon-server-edit {
    background-image:url(../icons/server_edit.png) !important;
}
.icon-server-error {
    background-image:url(../icons/server_error.png) !important;
}
.icon-server-go {
    background-image:url(../icons/server_go.png) !important;
}
.icon-server-key {
    background-image:url(../icons/server_key.png) !important;
}
.icon-server-lightning {
    background-image:url(../icons/server_lightning.png) !important;
}
.icon-server-link {
    background-image:url(../icons/server_link.png) !important;
}
.icon-server-uncompressed {
    background-image:url(../icons/server_uncompressed.png) !important;
}
.icon-shading {
    background-image:url(../icons/shading.png) !important;
}
.icon-shape-align-bottom {
    background-image:url(../icons/shape_align_bottom.png) !important;
}
.icon-shape-align-center {
    background-image:url(../icons/shape_align_center.png) !important;
}
.icon-shape-align-left {
    background-image:url(../icons/shape_align_left.png) !important;
}
.icon-shape-align-middle {
    background-image:url(../icons/shape_align_middle.png) !important;
}
.icon-shape-align-right {
    background-image:url(../icons/shape_align_right.png) !important;
}
.icon-shape-align-top {
    background-image:url(../icons/shape_align_top.png) !important;
}
.icon-shape-flip-horizontal {
    background-image:url(../icons/shape_flip_horizontal.png) !important;
}
.icon-shape-flip-vertical {
    background-image:url(../icons/shape_flip_vertical.png) !important;
}
.icon-shape-group {
    background-image:url(../icons/shape_group.png) !important;
}
.icon-shape-handles {
    background-image:url(../icons/shape_handles.png) !important;
}
.icon-shape-move-back {
    background-image:url(../icons/shape_move_back.png) !important;
}
.icon-shape-move-backwards {
    background-image:url(../icons/shape_move_backwards.png) !important;
}
.icon-shape-move-forwards {
    background-image:url(../icons/shape_move_forwards.png) !important;
}
.icon-shape-move-front {
    background-image:url(../icons/shape_move_front.png) !important;
}
.icon-shape-rotate-anticlockwise {
    background-image:url(../icons/shape_rotate_anticlockwise.png) !important;
}
.icon-shape-rotate-clockwise {
    background-image:url(../icons/shape_rotate_clockwise.png) !important;
}
.icon-shape-square {
    background-image:url(../icons/shape_square.png) !important;
}
.icon-shape-square-add {
    background-image:url(../icons/shape_square_add.png) !important;
}
.icon-shape-square-delete {
    background-image:url(../icons/shape_square_delete.png) !important;
}
.icon-shape-square-edit {
    background-image:url(../icons/shape_square_edit.png) !important;
}
.icon-shape-square-error {
    background-image:url(../icons/shape_square_error.png) !important;
}
.icon-shape-square-go {
    background-image:url(../icons/shape_square_go.png) !important;
}
.icon-shape-square-key {
    background-image:url(../icons/shape_square_key.png) !important;
}
.icon-shape-square-link {
    background-image:url(../icons/shape_square_link.png) !important;
}
.icon-shape-ungroup {
    background-image:url(../icons/shape_ungroup.png) !important;
}
.icon-shield {
    background-image:url(../icons/shield.png) !important;
}
.icon-shield-add {
    background-image:url(../icons/shield_add.png) !important;
}
.icon-shield-delete {
    background-image:url(../icons/shield_delete.png) !important;
}
.icon-shield-go {
    background-image:url(../icons/shield_go.png) !important;
}
.icon-sitemap {
    background-image:url(../icons/sitemap.png) !important;
}
.icon-sitemap-color {
    background-image:url(../icons/sitemap_color.png) !important;
}
.icon-sound {
    background-image:url(../icons/sound.png) !important;
}
.icon-sound-add {
    background-image:url(../icons/sound_add.png) !important;
}
.icon-sound-delete {
    background-image:url(../icons/sound_delete.png) !important;
}
.icon-sound-low {
    background-image:url(../icons/sound_low.png) !important;
}
.icon-sound-mute {
    background-image:url(../icons/sound_mute.png) !important;
}
.icon-sound-none {
    background-image:url(../icons/sound_none.png) !important;
}
.icon-spellcheck {
    background-image:url(../icons/spellcheck.png) !important;
}
.icon-sport-8ball {
    background-image:url(../icons/sport_8ball.png) !important;
}
.icon-sport-basketball {
    background-image:url(../icons/sport_basketball.png) !important;
}
.icon-sport-football {
    background-image:url(../icons/sport_football.png) !important;
}
.icon-sport-golf {
    background-image:url(../icons/sport_golf.png) !important;
}
.icon-sport-raquet {
    background-image:url(../icons/sport_raquet.png) !important;
}
.icon-sport-shuttlecock {
    background-image:url(../icons/sport_shuttlecock.png) !important;
}
.icon-sport-soccer {
    background-image:url(../icons/sport_soccer.png) !important;
}
.icon-sport-tennis {
    background-image:url(../icons/sport_tennis.png) !important;
}
.icon-star {
    background-image:url(../icons/star.png) !important;
}
.icon-status-away {
    background-image:url(../icons/status_away.png) !important;
}
.icon-status-busy {
    background-image:url(../icons/status_busy.png) !important;
}
.icon-status-offline {
    background-image:url(../icons/status_offline.png) !important;
}
.icon-status-online {
    background-image:url(../icons/status_online.png) !important;
}
.icon-stop {
    background-image:url(../icons/stop.png) !important;
}
.icon-style {
    background-image:url(../icons/style.png) !important;
}
.icon-style-add {
    background-image:url(../icons/style_add.png) !important;
}
.icon-style-delete {
    background-image:url(../icons/style_delete.png) !important;
}
.icon-style-edit {
    background-image:url(../icons/style_edit.png) !important;
}
.icon-style-go {
    background-image:url(../icons/style_go.png) !important;
}
.icon-sum {
    background-image:url(../icons/sum.png) !important;
}
.icon-tab {
    background-image:url(../icons/tab.png) !important;
}
.icon-table {
    background-image:url(../icons/table.png) !important;
}
.icon-table-add {
    background-image:url(../icons/table_add.png) !important;
}
.icon-table-delete {
    background-image:url(../icons/table_delete.png) !important;
}
.icon-table-edit {
    background-image:url(../icons/table_edit.png) !important;
}
.icon-table-error {
    background-image:url(../icons/table_error.png) !important;
}
.icon-table-gear {
    background-image:url(../icons/table_gear.png) !important;
}
.icon-table-go {
    background-image:url(../icons/table_go.png) !important;
}
.icon-table-key {
    background-image:url(../icons/table_key.png) !important;
}
.icon-table-lightning {
    background-image:url(../icons/table_lightning.png) !important;
}
.icon-table-link {
    background-image:url(../icons/table_link.png) !important;
}
.icon-table-multiple {
    background-image:url(../icons/table_multiple.png) !important;
}
.icon-table-refresh {
    background-image:url(../icons/table_refresh.png) !important;
}
.icon-table-relationship {
    background-image:url(../icons/table_relationship.png) !important;
}
.icon-table-row-delete {
    background-image:url(../icons/table_row_delete.png) !important;
}
.icon-table-row-insert {
    background-image:url(../icons/table_row_insert.png) !important;
}
.icon-table-save {
    background-image:url(../icons/table_save.png) !important;
}
.icon-table-sort {
    background-image:url(../icons/table_sort.png) !important;
}
.icon-tab-add {
    background-image:url(../icons/tab_add.png) !important;
}
.icon-tab-delete {
    background-image:url(../icons/tab_delete.png) !important;
}
.icon-tab-edit {
    background-image:url(../icons/tab_edit.png) !important;
}
.icon-tab-go {
    background-image:url(../icons/tab_go.png) !important;
}
.icon-tag {
    background-image:url(../icons/tag.png) !important;
}
.icon-tag-blue {
    background-image:url(../icons/tag_blue.png) !important;
}
.icon-tag-blue-add {
    background-image:url(../icons/tag_blue_add.png) !important;
}
.icon-tag-blue-delete {
    background-image:url(../icons/tag_blue_delete.png) !important;
}
.icon-tag-blue-edit {
    background-image:url(../icons/tag_blue_edit.png) !important;
}
.icon-tag-green {
    background-image:url(../icons/tag_green.png) !important;
}
.icon-tag-orange {
    background-image:url(../icons/tag_orange.png) !important;
}
.icon-tag-pink {
    background-image:url(../icons/tag_pink.png) !important;
}
.icon-tag-purple {
    background-image:url(../icons/tag_purple.png) !important;
}
.icon-tag-red {
    background-image:url(../icons/tag_red.png) !important;
}
.icon-tag-yellow {
    background-image:url(../icons/tag_yellow.png) !important;
}
.icon-telephone {
    background-image:url(../icons/telephone.png) !important;
}
.icon-telephone-add {
    background-image:url(../icons/telephone_add.png) !important;
}
.icon-telephone-delete {
    background-image:url(../icons/telephone_delete.png) !important;
}
.icon-telephone-edit {
    background-image:url(../icons/telephone_edit.png) !important;
}
.icon-telephone-error {
    background-image:url(../icons/telephone_error.png) !important;
}
.icon-telephone-go {
    background-image:url(../icons/telephone_go.png) !important;
}
.icon-telephone-key {
    background-image:url(../icons/telephone_key.png) !important;
}
.icon-telephone-link {
    background-image:url(../icons/telephone_link.png) !important;
}
.icon-television {
    background-image:url(../icons/television.png) !important;
}
.icon-television-add {
    background-image:url(../icons/television_add.png) !important;
}
.icon-television-delete {
    background-image:url(../icons/television_delete.png) !important;
}
.icon-textfield {
    background-image:url(../icons/textfield.png) !important;
}
.icon-textfield-add {
    background-image:url(../icons/textfield_add.png) !important;
}
.icon-textfield-delete {
    background-image:url(../icons/textfield_delete.png) !important;
}
.icon-textfield-key {
    background-image:url(../icons/textfield_key.png) !important;
}
.icon-textfield-rename {
    background-image:url(../icons/textfield_rename.png) !important;
}
.icon-text-align-center {
    background-image:url(../icons/text_align_center.png) !important;
}
.icon-text-align-justify {
    background-image:url(../icons/text_align_justify.png) !important;
}
.icon-text-align-left {
    background-image:url(../icons/text_align_left.png) !important;
}
.icon-text-align-right {
    background-image:url(../icons/text_align_right.png) !important;
}
.icon-text-allcaps {
    background-image:url(../icons/text_allcaps.png) !important;
}
.icon-text-bold {
    background-image:url(../icons/text_bold.png) !important;
}
.icon-text-columns {
    background-image:url(../icons/text_columns.png) !important;
}
.icon-text-dropcaps {
    background-image:url(../icons/text_dropcaps.png) !important;
}
.icon-text-heading-1 {
    background-image:url(../icons/text_heading_1.png) !important;
}
.icon-text-heading-2 {
    background-image:url(../icons/text_heading_2.png) !important;
}
.icon-text-heading-3 {
    background-image:url(../icons/text_heading_3.png) !important;
}
.icon-text-heading-4 {
    background-image:url(../icons/text_heading_4.png) !important;
}
.icon-text-heading-5 {
    background-image:url(../icons/text_heading_5.png) !important;
}
.icon-text-heading-6 {
    background-image:url(../icons/text_heading_6.png) !important;
}
.icon-text-horizontalrule {
    background-image:url(../icons/text_horizontalrule.png) !important;
}
.icon-text-indent {
    background-image:url(../icons/text_indent.png) !important;
}
.icon-text-indent-remove {
    background-image:url(../icons/text_indent_remove.png) !important;
}
.icon-text-italic {
    background-image:url(../icons/text_italic.png) !important;
}
.icon-text-kerning {
    background-image:url(../icons/text_kerning.png) !important;
}
.icon-text-letterspacing {
    background-image:url(../icons/text_letterspacing.png) !important;
}
.icon-text-letter-omega {
    background-image:url(../icons/text_letter_omega.png) !important;
}
.icon-text-linespacing {
    background-image:url(../icons/text_linespacing.png) !important;
}
.icon-text-list-bullets {
    background-image:url(../icons/text_list_bullets.png) !important;
}
.icon-text-list-numbers {
    background-image:url(../icons/text_list_numbers.png) !important;
}
.icon-text-lowercase {
    background-image:url(../icons/text_lowercase.png) !important;
}
.icon-text-padding-bottom {
    background-image:url(../icons/text_padding_bottom.png) !important;
}
.icon-text-padding-left {
    background-image:url(../icons/text_padding_left.png) !important;
}
.icon-text-padding-right {
    background-image:url(../icons/text_padding_right.png) !important;
}
.icon-text-padding-top {
    background-image:url(../icons/text_padding_top.png) !important;
}
.icon-text-replace {
    background-image:url(../icons/text_replace.png) !important;
}
.icon-text-signature {
    background-image:url(../icons/text_signature.png) !important;
}
.icon-text-smallcaps {
    background-image:url(../icons/text_smallcaps.png) !important;
}
.icon-text-strikethrough {
    background-image:url(../icons/text_strikethrough.png) !important;
}
.icon-text-subscript {
    background-image:url(../icons/text_subscript.png) !important;
}
.icon-text-superscript {
    background-image:url(../icons/text_superscript.png) !important;
}
.icon-text-underline {
    background-image:url(../icons/text_underline.png) !important;
}
.icon-text-uppercase {
    background-image:url(../icons/text_uppercase.png) !important;
}
.icon-thumb-down {
    background-image:url(../icons/thumb_down.png) !important;
}
.icon-thumb-up {
    background-image:url(../icons/thumb_up.png) !important;
}
.icon-tick {
    background-image:url(../icons/tick.png) !important;
}
.icon-time {
    background-image:url(../icons/time.png) !important;
}
.icon-timeline-marker {
    background-image:url(../icons/timeline_marker.png) !important;
}
.icon-time-add {
    background-image:url(../icons/time_add.png) !important;
}
.icon-time-delete {
    background-image:url(../icons/time_delete.png) !important;
}
.icon-time-go {
    background-image:url(../icons/time_go.png) !important;
}
.icon-transmit {
    background-image:url(../icons/transmit.png) !important;
}
.icon-transmit-add {
    background-image:url(../icons/transmit_add.png) !important;
}
.icon-transmit-blue {
    background-image:url(../icons/transmit_blue.png) !important;
}
.icon-transmit-delete {
    background-image:url(../icons/transmit_delete.png) !important;
}
.icon-transmit-edit {
    background-image:url(../icons/transmit_edit.png) !important;
}
.icon-transmit-error {
    background-image:url(../icons/transmit_error.png) !important;
}
.icon-transmit-go {
    background-image:url(../icons/transmit_go.png) !important;
}
.icon-tux {
    background-image:url(../icons/tux.png) !important;
}
.icon-user {
    background-image:url(../icons/user.png) !important;
}
.icon-user-add {
    background-image:url(../icons/user_add.png) !important;
}
.icon-user-comment {
    background-image:url(../icons/user_comment.png) !important;
}
.icon-user-delete {
    background-image:url(../icons/user_delete.png) !important;
}
.icon-user-edit {
    background-image:url(../icons/user_edit.png) !important;
}
.icon-user-female {
    background-image:url(../icons/user_female.png) !important;
}
.icon-user-go {
    background-image:url(../icons/user_go.png) !important;
}
.icon-user-gray {
    background-image:url(../icons/user_gray.png) !important;
}
.icon-user-green {
    background-image:url(../icons/user_green.png) !important;
}
.icon-user-orange {
    background-image:url(../icons/user_orange.png) !important;
}
.icon-user-red {
    background-image:url(../icons/user_red.png) !important;
}
.icon-user-suit {
    background-image:url(../icons/user_suit.png) !important;
}
.icon-vcard {
    background-image:url(../icons/vcard.png) !important;
}
.icon-vcard-add {
    background-image:url(../icons/vcard_add.png) !important;
}
.icon-vcard-delete {
    background-image:url(../icons/vcard_delete.png) !important;
}
.icon-vcard-edit {
    background-image:url(../icons/vcard_edit.png) !important;
}
.icon-vector {
    background-image:url(../icons/vector.png) !important;
}
.icon-vector-add {
    background-image:url(../icons/vector_add.png) !important;
}
.icon-vector-delete {
    background-image:url(../icons/vector_delete.png) !important;
}
.icon-wand {
    background-image:url(../icons/wand.png) !important;
}
.icon-weather-clouds {
    background-image:url(../icons/weather_clouds.png) !important;
}
.icon-weather-cloudy {
    background-image:url(../icons/weather_cloudy.png) !important;
}
.icon-weather-lightning {
    background-image:url(../icons/weather_lightning.png) !important;
}
.icon-weather-rain {
    background-image:url(../icons/weather_rain.png) !important;
}
.icon-weather-snow {
    background-image:url(../icons/weather_snow.png) !important;
}
.icon-weather-sun {
    background-image:url(../icons/weather_sun.png) !important;
}
.icon-webcam {
    background-image:url(../icons/webcam.png) !important;
}
.icon-webcam-add {
    background-image:url(../icons/webcam_add.png) !important;
}
.icon-webcam-delete {
    background-image:url(../icons/webcam_delete.png) !important;
}
.icon-webcam-error {
    background-image:url(../icons/webcam_error.png) !important;
}
.icon-world {
    background-image:url(../icons/world.png) !important;
}
.icon-world-add {
    background-image:url(../icons/world_add.png) !important;
}
.icon-world-delete {
    background-image:url(../icons/world_delete.png) !important;
}
.icon-world-edit {
    background-image:url(../icons/world_edit.png) !important;
}
.icon-world-go {
    background-image:url(../icons/world_go.png) !important;
}
.icon-world-link {
    background-image:url(../icons/world_link.png) !important;
}
.icon-wrench {
    background-image:url(../icons/wrench.png) !important;
}
.icon-wrench-orange {
    background-image:url(../icons/wrench_orange.png) !important;
}
.icon-xhtml {
    background-image:url(../icons/xhtml.png) !important;
}
.icon-xhtml-add {
    background-image:url(../icons/xhtml_add.png) !important;
}
.icon-xhtml-delete {
    background-image:url(../icons/xhtml_delete.png) !important;
}
.icon-xhtml-go {
    background-image:url(../icons/xhtml_go.png) !important;
}
.icon-xhtml-valid {
    background-image:url(../icons/xhtml_valid.png) !important;
}
.icon-zoom {
    background-image:url(../icons/zoom.png) !important;
}
.icon-zoom-in {
    background-image:url(../icons/zoom_in.png) !important;
}
.icon-zoom-out {
    background-image:url(../icons/zoom_out.png) !important;
}
.icon-page-white-js {
    background-image:url(../icons/page_white_js.png) !important;
}
.icon-page-white-py {
    background-image:url(../icons/page_white_py.png) !important;
}
.icon-page-white-py {
    background-image:url(../icons/page_white_py.png) !important;
}
.icon-package-py {
    background-image:url(../icons/package_py.png) !important;
}
.icon-tree-expand{
    background-image:url(../icons/tree_expand.png) !important;
}
.icon-tree-collapse{
    background-image:url(../icons/tree_collapse.png) !important;
}
