.x-grid3-total-summary{
    background-color:#f9f9f9;
    background-repeat: repeat-x;
    background-position: left top;
}

.x-grid3-total-summary-inner {
    overflow:hidden;
    zoom:1;
    float:left;
}

.x-grid3-total-summary-offset {
    padding-left:1px;
    text-align: left;
}

.x-grid3-total-summary-row {
    border-left-color:#eee;
    border-right-color:#d0d0d0;
}
