{% extends 'm3_master.html' %}

{% block content_head %}
    <script type="text/javascript">
        // конфигурация Рабочего Стола в виде JSON
        var desktopConfig = {{ desktop|safe }};
        var params = {
            addDesktopItemUrl: '{{ add_desktop_item_url }}',
            removeDesktopItemUrl: '{{ remove_desktop_item_url }}',
            enableDragAndDrop: {{ enable_drag_and_drop|default:'false' }},
            startMenuText: '{{ start_menu_text }}' || '{{ user }}',
            startMenuIcon: '{{ start_menu_icon }}' || '{{ user_icon }}',
            extra: {{ extra_params|safe|default:'{}' }},
            useMenuSearch: {{ use_menu_search|lower|default:'false' }},
        };
        AppDesktop = new Ext.app.App(desktopConfig, params);
    </script>
    {% block extra_head %}
    {% endblock %}
{% endblock %}

{% block content %}
    <!-- Верхняя панель -->
    <div id="ux-toptoolbar"></div>

    <!-- Верхняя панель -->
    <div id="x-desktop">
        <table id="x-shortcuts">
            <tr>
                <!-- Иконки в десктопе -->
                {% for item in desktop_icons %}
                <td id="desktop-item-{{ item.0 }}-shortcut">
                    <a href="#">
                    <div class="base-desktop-image {{ item.2 }}"> </div>
                    <div class="desktop-item-shortcut-label">{{ item.1 }}</div>
                    </a>
                </td>
                {% endfor %}
            </tr>
        </table>

    <!-- Виджеты раб.стола -->
    {% block desktop_widgets %}
    {% endblock %}

    </div>

    {% block extra_content %}
    {% endblock %}

    <!-- Нижняя панель и меню пуск -->
    <div id="ux-taskbar">
        <div id="ux-taskbar-start"></div>
        <div id="ux-taskbuttons-panel"></div>
        <div class="x-clear"></div>
    </div>
{% endblock %}
